@@ -21,8 +21,7 @@
 
 #include <stdlib.h>
 
-#include <libdivecomputer/cressi_leonardo.h>
-
+#include "cressi_leonardo.h"
 #include "context-private.h"
 #include "parser-private.h"
 #include "array.h"
@@ -47,7 +46,7 @@ static dc_status_t cressi_leonardo_parser_samples_foreach (dc_parser_t *abstract
 
 static const dc_parser_vtable_t cressi_leonardo_parser_vtable = {
 	sizeof(cressi_leonardo_parser_t),
-	DC_FAMILY_CRESSI_EDY,
+	DC_FAMILY_CRESSI_LEONARDO,
 	cressi_leonardo_parser_set_data, /* set_data */
 	cressi_leonardo_parser_get_datetime, /* datetime */
 	cressi_leonardo_parser_get_field, /* fields */
@@ -57,7 +56,7 @@ static const dc_parser_vtable_t cressi_leonardo_parser_vtable = {
 
 
 dc_status_t
-cressi_leonardo_parser_create2 (dc_parser_t **out, dc_context_t *context, unsigned int model)
+cressi_leonardo_parser_create (dc_parser_t **out, dc_context_t *context, unsigned int model)
 {
 	cressi_leonardo_parser_t *parser = NULL;
 
@@ -79,13 +78,6 @@ cressi_leonardo_parser_create2 (dc_parser_t **out, dc_context_t *context, unsign
 }
 
 
-dc_status_t
-cressi_leonardo_parser_create (dc_parser_t **parser, dc_context_t *context)
-{
-	return cressi_leonardo_parser_create2 (parser, context, 0);
-}
-
-
 static dc_status_t
 cressi_leonardo_parser_set_data (dc_parser_t *abstract, const unsigned char *data, unsigned int size)
 {
@@ -108,6 +100,7 @@ cressi_leonardo_parser_get_datetime (dc_parser_t *abstract, dc_datetime_t *datet
 		datetime->hour = p[11];
 		datetime->minute = p[12];
 		datetime->second = 0;
+		datetime->timezone = DC_TIMEZONE_NONE;
 	}
 
 	return DC_STATUS_SUCCESS;
@@ -185,6 +178,9 @@ cressi_leonardo_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callbac
 
 	unsigned int gasmix_previous = 0xFFFFFFFF;
 	unsigned int gasmix = 0;
+	if (parser->model == DRAKE) {
+		gasmix = gasmix_previous;
+	}
 
 	unsigned int offset = SZ_HEADER;
 	while (offset + 2 <= size) {
