@@ -21,9 +21,9 @@
 
 #include <stdlib.h>	// malloc, free
 
-#include <libdivecomputer/reefnet_sensus.h>
 #include <libdivecomputer/units.h>
 
+#include "reefnet_sensus.h"
 #include "context-private.h"
 #include "parser-private.h"
 #include "array.h"
@@ -133,7 +133,12 @@ reefnet_sensus_parser_get_datetime (dc_parser_t *abstract, dc_datetime_t *dateti
 
 	unsigned int timestamp = array_uint32_le (abstract->data + 2);
 
-	dc_ticks_t ticks = parser->systime - (parser->devtime - timestamp);
+	dc_ticks_t ticks = parser->systime;
+	if (timestamp < parser->devtime) {
+		ticks -= parser->devtime - timestamp;
+	} else {
+		ticks += timestamp - parser->devtime;
+	}
 
 	if (!dc_datetime_localtime (datetime, ticks))
 		return DC_STATUS_DATAFORMAT;
